tsseg.algorithms.e2usd package
==============================

Deep learning: DDEM for temporal representations + DPGMM clustering.

| **Type:** state detection
| **Supervision:** unsupervised or semi-supervised
| **Requires:** PyTorch

**Implementation:** Taken from https://github.com/AI4CTS/E2Usd. No licence found.

**Reference:** Chen et al. (2024), WWW.

Submodules
----------

tsseg.algorithms.e2usd.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.e2usd.detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.e2usd.e2usd module
-----------------------------------

.. automodule:: tsseg.algorithms.e2usd.e2usd
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.e2usd
   :members:
   :show-inheritance:
   :undoc-members:
